meta_package_manager.managers.pip — Meta Package Manager 2.4.1 documentation

# `meta_package_manager.managers.pip`

class `meta_package_manager.managers.pip.` `Pip`

  Bases: `meta_package_manager.base.PackageManager`

  `platforms` = frozenset([u'macos', u'linux'])
  `get_version`()

    Fetch version from `pip --version` output.

  `installed`

    Fetch installed packages from `pip list` output.

    Raw CLI output samples:

        $ pip list
        configparser (3.5.0)
        docutils (0.13.1)
        html5lib (0.9999999)
        imagesize (0.7.1)
        MarkupSafe (0.23)
        mccabe (0.5.3)
        meta-package-manager (2.4.0, /home/kev/venvs/meta-package-manager)
        nose (1.3.7)

  `outdated`

    Fetch outdated packages from `pip list --outdated` output.

    Raw CLI output samples:

        $ pip list --outdated
        ccm (2.1.8, /Users/kdeldycke/ccm) - Latest: 2.1.11 [sdist]
        coverage (4.0.3) - Latest: 4.1 [wheel]
        IMAPClient (0.13) - Latest: 1.0.1 [wheel]
        Logbook (0.10.1) - Latest: 1.0.0 [sdist]
        mccabe (0.4.0) - Latest: 0.5.0 [wheel]
        mercurial (3.8.3) - Latest: 3.8.4 [sdist]
        pylint (1.5.6) - Latest: 1.6.1 [wheel]

  `upgrade_cli`(package_id)
  `upgrade_all_cli`()

    Pip lacks support of a proper full upgrade command.

    See: https://github.com/pypa/pip/issues/59

class `meta_package_manager.managers.pip.` `Pip2`

  Bases: `meta_package_manager.managers.pip.Pip`

  `cli_path` = u'/usr/local/bin/pip2'
  `name` = u"Python 2's Pip"

class `meta_package_manager.managers.pip.` `Pip3`

  Bases: `meta_package_manager.managers.pip.Pip`

  `cli_path` = u'/usr/local/bin/pip3'
  `name` = u"Python 3's Pip"